@@ -147,6 +147,15 @@ int apm_exists(void)
 		return 0;
 	return apm_read(&i);
 }
+#elif !defined(HAVE_LIBAPM)
+int apm_read(apm_info *i)
+{
+	return -1;
+}
+int apm_exists(void)
+{
+	return -1;
+}
 #endif
 
 int apm_change(apm_info *cur)
@@ -788,8 +797,10 @@ int main(int argc, char *argv[])
 	}
 #endif
 #ifdef UPOWER
-	else if (upower_supported())
+	else if (upower_supported()) {
 		use_upower = 1;
+		delay = 2;
+	}
 #endif
 	/* Check for ACPI support. */
 	else if (acpi_supported() && acpi_batt_count > 0) {
